django-jinja
============

Simple and nonobstructive jinja2 integration with Django.

**Documentation:** https://django-jinja.readthedocs.org/


How to install?
---------------

You can install it with pip:

.. code-block:: shell

    pip install django-jinja

